#Script to analyse the qualitative MS data from P3E35c 

#set WD
setwd("YOUR DIR - SET AS SAME LOC AS INPUT FILES ")

#load packages
require(tidyverse)
require(ggplot2)
require(RColorBrewer)
require(ggrepel)

#1.1) Analyse and Load data  from PRIDE: PXD022520 and 10.6019/PXD022520
Organoid_MS <- read.csv("2019_10_24_CB_P3E35c_II_Protein.csv", sep = ",", header = TRUE)[read.csv("2019_10_24_CB_P3E35c_II_Protein.csv", sep = ",", header = TRUE)$Protein.FDR.Confidence == "High" 
                                                                           & read.csv("2019_10_24_CB_P3E35c_II_Protein.csv", sep = ",", header = TRUE)$X..Unique.Peptides >= 2,
                                                                           ] %>% 
  separate(Description, into = c("Full_Name", "Species", "Gene_name", "Number"), sep = "=") %>%
  separate(Gene_name, into = c("Gene_name", "a"), sep = "\\s") %>%
  select(Accession, Gene_name, X..Unique.Peptides) 

#Save Masterlist and upload to DAVID for GO_BP annotation and generate plot
write.csv(Organoid_MS, file = "./MS_SF14_Masterlist.csv", row.names = FALSE)

#1.2) Visulaize BP-GO annotations
#Read GO_BP file
Organoid_BP <- read.csv("2020_01_29_GO_BP_Annotation.csv", header = TRUE, sep = ",")[read.csv("2020_01_29_GO_BP_Annotation.csv", header = TRUE, sep = ",")$FDR <= 0.05
                                                                                 & read.csv("2020_01_29_GO_BP_Annotation.csv", header = TRUE, sep = ",")$PValue <= 0.05
                                                                                 & read.csv("2020_01_29_GO_BP_Annotation.csv", header = TRUE, sep = ",")$Fold.Enrichment >= 1.5,
                                                                                 ] %>% mutate(Log10_PValue = -log10(PValue),
                                                                                              Log10_FDR = -log10(FDR)
                                                                                 )%>% separate(Term, c("Term_NO", "Term_Name"), remove = FALSE, sep = "~")
Organoid_BP <- Organoid_BP[1:30,]

#define colour palette 
myPalette <- colorRampPalette(rev(brewer.pal(11, "Spectral")))
sc_Organoid <- scale_colour_gradientn(colours = myPalette(100), limits=c(10, 70))

#Plot the GOTERM results 
out_1 <- ggplot(Organoid_BP, aes(x=Fold.Enrichment, y=Log10_PValue, color=Log10_PValue, size=Count)) + 
  geom_point()+
  theme_classic(base_size = 16)+
  labs(x = "Fold Enrichment", y = "-Log10(p-Value)")+
  sc_Organoid+
  geom_text_repel(label=Organoid_BP$Term_Name ,box.padding = unit(0.7, "lines"),
                  point.padding = unit(0.5, "lines"))+
  scale_size(range = c(1, 10))+
  theme(aspect.ratio=1)

ggsave("./SF14_BP_plot.pdf", out_1, device = "pdf", width = 10, height = 10, unit = "in")

#1.3) Visulaize KEGG Pathway annotation
Organoid_KEGG <- read.csv("2020_01_30 KEGG_annotation.csv", header = TRUE, sep = ",")[read.csv("2020_01_30 KEGG_annotation.csv", header = TRUE, sep = ",")$FDR <= 0.05
                                                                                     & read.csv("2020_01_30 KEGG_annotation.csv", header = TRUE, sep = ",")$PValue <= 0.05
                                                                                     & read.csv("2020_01_30 KEGG_annotation.csv", header = TRUE, sep = ",")$Fold.Enrichment >= 1.5,
                                                                                     ] %>% mutate(Log10_PValue = -log10(PValue),
                                                                                                  Log10_FDR = -log10(FDR)
                                                                                     )%>% separate(Term, c("Term_NO", "Term_Name"), remove = FALSE, sep = ":")

Organoid_KEGG <- Organoid_KEGG[1:20,]

out_2 <- ggplot(Organoid_KEGG, aes(y = Log10_PValue, reorder(Term_Name, Log10_PValue))) +
  geom_bar(stat = "identity", color = "white", fill = "black", width = 1)+
  coord_flip()+
  theme_classic(base_size = 16)+
  ylim(0, 30)

aspect_ratio <- 1.5
ggsave("SF14_KEGG_plot.pdf", plot = out_2, device = "pdf", height = 5* aspect_ratio , width = 7)



#2) Annotate Masterfile against matrisome and integrins to generate cytoscape plot use integrin interaction db from "F_2020_SF7a-f_CDM.zip"
#Annotate Integrins
UIshort <- read.csv("./databases/2020_SF7c_Unique_Integrins.csv", header = TRUE, sep = ",")
Matrisome <- read.csv("./databases/matrisome_mm_masterlist.csv", sep = ",", header = TRUE) %>% select(Gene.Symbol, Division, Category)
names(Matrisome)[names(Matrisome) == 'Gene.Symbol'] <- 'Gene_name'

Organoid_Integrins <- merge(Organoid_MS, UIshort, by = "Gene_name") %>% 
  mutate(Division = "Integrins", Category = "Integrins")

Organoid_MA <- merge(Organoid_MS, Matrisome, by = "Gene_name")

#Combine MA and Integrins in full Matrisome
Organoid_MAint <- rbind(Organoid_Integrins, Organoid_MA)

#Save MAint file for Cytoscape
write.csv(Organoid_MAint, file = "SF4_Annotated_Matrisome_integrins.csv", row.names = F)

#Generate interactions 
#1) Load full formatted Itga - ECM interactions database that was created in the F_2020_SF7a-f_CDM.zip
IntInts <- read.csv("./databases/2020_SF7c_Integrin_Interactions.csv", header = TRUE, sep = ",")

#2) Generate a file containing all interactions from identified integrins to all ECM proteins - then subtract all non-identified matrix proteins 
#File for Interactions of all detected integrins
OIntegrin_Interactions <- inner_join(IntInts, Organoid_Integrins, by = c("A" = "Gene_name"))

#Subtract non_detected integrins
OIntegrin_Interactions <- inner_join(OIntegrin_Interactions, Organoid_MA, by = c("B" = "Gene_name"))

#Save file
write.csv(OIntegrin_Interactions, file = "SF4_Detected_Int-ECM_Interactions.csv", row.names = FALSE)
